@@ -8,7 +8,7 @@ package App::MatrixTool;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Getopt::Long qw( GetOptionsFromArray );
 use Future;
@@ -62,17 +62,19 @@ readonly_struct OptSpec => [qw( name print_name shortname getopt description )];
 sub OPTSPECS
 {
    pairmap {
-      my $getopt = $a;
+      my ( $name, $desc ) = ( $a, $b ); # allocate new SVtPVs to placate odd COW-related bug in 5.18
 
-      $a =~ s/=.*//;
+      my $getopt = $name;
+
+      $name =~ s/=.*//;
 
       my $shortname;
-      $a =~ s/^(.)\|// and $shortname = $1;
+      $name =~ s/^(.)\|// and $shortname = $1;
 
-      my $printname = "$a";  # stringify to allocate a new SVtPV - RT95409
-      $a =~ s/-/_/g;
+      my $printname = $name;
+      $name =~ s/-/_/g;
 
-      OptSpec( $a, $printname, $shortname, $getopt, $b )
+      OptSpec( $name, $printname, $shortname, $getopt, $desc )
    } shift->OPTIONS;
 }
 
